]> granicus.if.org Git - neomutt/commitdiff
rename: Unify the multi-byte char table naming
authorRichard Russon <rich@flatcap.org>
Fri, 1 Sep 2017 19:46:23 +0000 (20:46 +0100)
committerRichard Russon <rich@flatcap.org>
Wed, 6 Sep 2017 01:40:22 +0000 (02:40 +0100)
Through the code this was referred to by the names:
- mbchar_table
- mbyte_table
- mbchartbl

ChangeLog.md
Makefile.am
contrib/lua/test_lua-api_spec.lua
globals.h
hdrline.c
init.c
mbtable.h [moved from mbyte_table.h with 88% similarity]
mutt_lua.c
status.c

index 4afc8dc4c26077d09f416790d1839aa5cbd08dc2..445ff2f0df4ad7f1a0cefae3dfc59fd0a2255123 100644 (file)
   - Rework OpenSSL certificate verification to support alternative chains. (closes #3903)
   - Add option to control whether threads uncollapse when new mail arrives.
   - In the manual, replaced 2 para by example (similar to the first example).
-  - Create mbchar_table type for multibyte character arrays. (see #3024)
+  - Create MbTable type for multibyte character arrays. (see #3024)
   - Make to_chars and status_chars accept mulitibyte characters. (closes #3024)
 
 2016-11-26  Richard Russon  <rich@flatcap.org>
index fc4742bb10e4afec14b186020b67507547c4068d..ac3a2f0e2f85beb5ade3528aad00a740b405d6c7 100644 (file)
@@ -50,7 +50,7 @@ mutt_SOURCES = account.c addrbook.c address.h alias.c alias.h attach.c \
        curs_lib.c curs_main.c edit.c editmsg.c enter.c enter_state.h \
        envelope.c envelope.h filter.c flags.c format_flags.h from.c getdomain.c group.c \
        handler.c hdrline.c header.h headers.c help.c history.c hook.c \
-       init.c keymap.c list.h main.c mbox.c mbyte.c mbyte_table.h \
+       init.c keymap.c list.h main.c mbox.c mbyte.c mbtable.h \
        menu.c mh.c muttlib.c mutt_idna.c mutt_sasl_plain.c mutt_socket.c \
        mutt_tunnel.c mx.c newsrc.c nntp.c options.h pager.c parameter.c parameter.h \
        parse.c pattern.c pattern.h pop.c pop_auth.c pop_lib.c postpone.c \
index 6ad7a17541acd34030fdb98c1f11fdf827dec561..70619f5a76a46d2bd2c1ef81bc0ed6d76526dea5 100644 (file)
@@ -76,7 +76,7 @@ describe('lua API', function()
       test_config_type("mask", "!^\\\\.[^.]", ".*")
     end)
 
-    it('works with DT_MBCHARTBL', function()
+    it('works with DT_MBTABLE', function()
       test_config_type("to_chars", "+TCFL", "+T")
     end)
 
index e5eebf20850d9ba2bc1a38cf0aaf2c698937b356..73054811d42ed4b2870488965b3b995d67b9c2a8 100644 (file)
--- a/globals.h
+++ b/globals.h
@@ -71,7 +71,7 @@ WHERE char *ForwardAttrIntro;
 WHERE char *ForwardAttrTrailer;
 WHERE char *ForwFmt;
 WHERE char *Fqdn;
-WHERE struct MbCharTable *FromChars;
+WHERE struct MbTable *FromChars;
 WHERE char *HdrFmt;
 WHERE char *HistFile;
 WHERE char *HomeDir;
@@ -178,11 +178,11 @@ WHERE short SslDHPrimeBits;
 WHERE char *SslCACertFile;
 #endif
 #endif
-WHERE struct MbCharTable *StChars;
+WHERE struct MbTable *StChars;
 WHERE char *Status;
 WHERE char *TempDir;
-WHERE struct MbCharTable *ToChars;
-WHERE struct MbCharTable *FlagChars;
+WHERE struct MbTable *ToChars;
+WHERE struct MbTable *FlagChars;
 WHERE char *TrashPath;
 WHERE char *TSStatusFormat;
 WHERE char *TSIconFormat;
index a5b1f5f0d1b2c12ba7efb8c685b05f3f4acf023c..f9360c59523a697dd1f185a43360718ccd011701 100644 (file)
--- a/hdrline.c
+++ b/hdrline.c
@@ -39,7 +39,7 @@
 #include "globals.h"
 #include "header.h"
 #include "lib/lib.h"
-#include "mbyte_table.h"
+#include "mbtable.h"
 #include "mutt_curses.h"
 #include "mutt_idna.h"
 #include "ncrypt/ncrypt.h"
@@ -205,7 +205,7 @@ enum FieldType
  * If the index is invalid, then a space character will be returned.
  * If the character selected is '\n' (Ctrl-M), then "" will be returned.
  */
-static char *get_nth_wchar(struct MbCharTable *table, int index)
+static char *get_nth_wchar(struct MbTable *table, int index)
 {
   if (!table || !table->chars || (index < 0) || (index >= table->len))
     return " ";
--- a/status.c
+++ b/status.c
@@ -26,7 +26,7 @@
 #include "format_flags.h"
 #include "globals.h"
 #include "lib/lib.h"
-#include "mbyte_table.h"
+#include "mbtable.h"
 #include "mutt_curses.h"
 #include "mutt_menu.h"
 #include "mx.h"
diff --git a/init.c b/init.c
index 1432ee6c3279224ba62a9694a3631d086cd81799..1b489809fa55d43bacc7a4aac4051b3b6fa69381 100644 (file)
--- a/init.c
+++ b/init.c
@@ -54,7 +54,7 @@
 #include "list.h"
 #include "mailbox.h"
 #include "mbyte.h"
-#include "mbyte_table.h"
+#include "mbtable.h"
 #include "mutt.h"
 #include "mutt_curses.h"
 #include "mutt_idna.h"
@@ -283,7 +283,7 @@ bool mutt_option_get(const char *s, struct Option *opt)
 }
 #endif
 
-static void free_mbchar_table(struct MbCharTable **t)
+static void free_mbtable(struct MbTable **t)
 {
   if (!t || !*t)
     return;
@@ -294,14 +294,14 @@ static void free_mbchar_table(struct MbCharTable **t)
   FREE(t);
 }
 
-static struct MbCharTable *parse_mbchar_table(const char *s)
+static struct MbTable *parse_mbtable(const char *s)
 {
-  struct MbCharTable *t = NULL;
+  struct MbTable *t = NULL;
   size_t slen, k;
   mbstate_t mbstate;
   char *d = NULL;
 
-  t = safe_calloc(1, sizeof(struct MbCharTable));
+  t = safe_calloc(1, sizeof(struct MbTable));
   slen = mutt_strlen(s);
   if (!slen)
     return t;
@@ -318,7 +318,7 @@ static struct MbCharTable *parse_mbchar_table(const char *s)
     if (k == (size_t)(-1) || k == (size_t)(-2))
     {
       mutt_debug(
-          1, "parse_mbchar_table: mbrtowc returned %d converting %s in %s\n",
+          1, "parse_mbtable: mbrtowc returned %d converting %s in %s\n",
           (k == (size_t)(-1)) ? -1 : -2, s, t->orig_str);
       if (k == (size_t)(-1))
         memset(&mbstate, 0, sizeof(mbstate));
@@ -452,9 +452,9 @@ int mutt_option_set(const struct Option *val, struct Buffer *err)
       break;
       case DT_MBTABLE:
       {
-        struct MbCharTable **tbl = (struct MbCharTable **) MuttVars[idx].data;
-        free_mbchar_table(tbl);
-        *tbl = parse_mbchar_table((const char *) val->data);
+        struct MbTable **tbl = (struct MbTable **) MuttVars[idx].data;
+        free_mbtable(tbl);
+        *tbl = parse_mbtable((const char *) val->data);
       }
       break;
       case DT_ADDRESS:
@@ -2083,8 +2083,8 @@ static void restore_default(struct Option *p)
       mutt_str_replace((char **) p->data, (char *) p->init);
       break;
     case DT_MBTABLE:
-      free_mbchar_table((struct MbCharTable **) p->data);
-      *((struct MbCharTable **) p->data) = parse_mbchar_table((char *) p->init);
+      free_mbtable((struct MbTable **) p->data);
+      *((struct MbTable **) p->data) = parse_mbtable((char *) p->init);
       break;
     case DT_PATH:
       FREE((char **) p->data);
@@ -2646,7 +2646,7 @@ static int parse_set(struct Buffer *tmp, struct Buffer *s, unsigned long data,
         else if (DTYPE(MuttVars[idx].type) == DT_ADDRESS)
           rfc822_free_address((struct Address **) MuttVars[idx].data);
         else if (DTYPE(MuttVars[idx].type) == DT_MBTABLE)
-          free_mbchar_table((struct MbCharTable **) MuttVars[idx].data);
+          free_mbtable((struct MbTable **) MuttVars[idx].data);
         else
           /* MuttVars[idx].data is already 'char**' (or some 'void**') or...
            * so cast to 'void*' is okay */
@@ -2686,7 +2686,7 @@ static int parse_set(struct Buffer *tmp, struct Buffer *s, unsigned long data,
         }
         else if (DTYPE(MuttVars[idx].type) == DT_MBTABLE)
         {
-          struct MbCharTable *mbt = (*((struct MbCharTable **) MuttVars[idx].data));
+          struct MbTable *mbt = (*((struct MbTable **) MuttVars[idx].data));
           val = mbt ? NONULL(mbt->orig_str) : "";
         }
         else
@@ -2768,8 +2768,8 @@ static int parse_set(struct Buffer *tmp, struct Buffer *s, unsigned long data,
         }
         else if (DTYPE(MuttVars[idx].type) == DT_MBTABLE)
         {
-          free_mbchar_table((struct MbCharTable **) MuttVars[idx].data);
-          *((struct MbCharTable **) MuttVars[idx].data) = parse_mbchar_table(tmp->data);
+          free_mbtable((struct MbTable **) MuttVars[idx].data);
+          *((struct MbTable **) MuttVars[idx].data) = parse_mbtable(tmp->data);
         }
         else
         {
@@ -3852,7 +3852,7 @@ int var_to_string(int idx, char *val, size_t len)
   }
   else if (DTYPE(MuttVars[idx].type) == DT_MBTABLE)
   {
-    struct MbCharTable *mbt = (*((struct MbCharTable **) MuttVars[idx].data));
+    struct MbTable *mbt = (*((struct MbTable **) MuttVars[idx].data));
     strfcpy(tmp, mbt ? NONULL(mbt->orig_str) : "", sizeof(tmp));
   }
   else if (DTYPE(MuttVars[idx].type) == DT_ADDRESS)
similarity index 88%
rename from mbyte_table.h
rename to mbtable.h
index 42cc4ba2da0b87f0c3f48dcc798cbaae68226670..d8ac109e830d41d2ce97982e491d72417512535a 100644 (file)
+++ b/mbtable.h
  * this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _MUTT_MBYTE_TABLE_H
-#define _MUTT_MBYTE_TABLE_H
+#ifndef _MUTT_MBTABLE_H
+#define _MUTT_MBTABLE_H
 
 /**
* struct MbCharTable - multibyte character table
  *
  * Allows for direct access to the individual multibyte characters in a
  * string.  This is used for the FlagChars, FromChars, StChars and ToChars
  * option types.
  */
-struct MbCharTable
+struct MbTable
 {
   int len;             /**< number of characters */
   char **chars;        /**< the array of multibyte character strings */
@@ -38,4 +38,4 @@ struct MbCharTable
   char *orig_str;
 };
 
-#endif /* _MUTT_MBYTE_TABLE_H */
+#endif /* _MUTT_MBTABLE_H */
index d23a307b19f30805757680c42d3bbd94ccec50f8..7c7d6166d5a629b48ec79a28f0e3df55be9ae11a 100644 (file)
@@ -34,7 +34,7 @@
 #include "globals.h"
 #include "lib/lib.h"
 #include "mailbox.h"
-#include "mbyte_table.h"
+#include "mbtable.h"
 #include "mutt_commands.h"
 #include "mutt_options.h"
 #include "options.h"
@@ -211,7 +211,7 @@ static int _lua_mutt_get(lua_State *l)
       }
       case DT_MBTABLE:
       {
-        struct MbCharTable *tbl = *(struct MbCharTable **) opt.data;
+        struct MbTable *tbl = *(struct MbTable **) opt.data;
         lua_pushstring(l, tbl->orig_str);
         return 1;
       }
@@ -3852,7 +3852,7 @@ int var_to_string(int idx, char *val, size_t len)
 
 /**
- * struct MbCharTable - multibyte character table
+ * struct MbTable - multibyte character table
  *
  * Allows for direct access to the individual multibyte characters in a
index 7c418856737fd56598e172c483898992c0fdddaf..d7fa3039f5c254e183ad9eec08ac114504c6d3de 100644 (file)